<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=km
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'ត្រលប់​ទៅ ផ្ទាំង​ប្រទាក់​ក្រាហ្វិក​ពេញលេញ​',
	'access_mode_texte' => 'បង្ហាញ​ចេញ ផ្ទាំង​ប្រទាក់​​សាមញ្ញ ជាអត្ថបទ',
	'admin_debug' => 'កែ​កំហុស',
	'admin_modifier_article' => 'កែប្រែ​ អត្ថបទ​នេះ',
	'admin_modifier_auteur' => 'ប្តូរ អ្នកនិពន្ធនេះ',
	'admin_modifier_breve' => 'ផ្លាស់ប្តូរ ពត៌មានខ្លី​នេះ',
	'admin_modifier_mot' => 'ផ្លាស់ប្តូរ ពាក្យ​គន្លឹះ​នេះ',
	'admin_modifier_rubrique' => 'ផ្លាល់ប្តូរ ​ផ្នែក​នេះ',
	'admin_recalculer' => 'កំណត់ឡើងវិញ ទំព័រនេះ',
	'afficher_trad' => 'បង្ហាញ​ចេញ បំរែសំរួល',
	'alerte_maj_impossible' => '<b>​ព្រមាន​!</b> គ្មានអាច បន្ទាន់សម័យ មូលដ្ឋានទិន្នន័យ SQL ទៅ​ កំណែ @version@, ប្រហែល បណ្តាលពី ​បញ្ហាសិទ្ធិផ្លាស់ប្តូរ ​លើ​មូលដ្ឋានទិន្នន័យ។ សូម​ទាក់ទង ខំព្យូរើផ្តល់ទីស្នាក់សៃថ៍ របស់​អ្នក។',
	'alerte_modif_info_concourante' => 'ប្រយត្ន៖ ពត៌មាននេះ ត្រូវបានផ្លាស់ប្តូរ ដោយទីដទៃ។ តំលៃបច្ចុប្បន្ន ជា ៖',
	'analyse_xml' => 'ការ​វិភាគ អក្សរកូដ XML',
	'annuler' => 'បោះបង់',
	'antispam_champ_vide' => 'សូម​ទុក វាល​នេះ​ នៅ​ទំនេរ ៖',
	'articles_recents' => 'អត្ថបទ​ថ្មី​ៗ បំផុត',
	'avis_archive_incorrect' => 'ឯកសារ​ ជាបណ្ណសារ មិន​ជា​ឯកសារ SPIP',
	'avis_archive_invalide' => 'ឯកសារ​ ជាបណ្ណសារ គ្មានសុពលភាព',
	'avis_attention' => 'ប្រយ័ត្ន !',
	'avis_champ_incorrect_type_objet' => 'ឈ្មោះ​វាល មិន​ត្រឹមត្រូវ @name@ ចំពោះ​ គោលដៅ ប្រភេទ @type@',
	'avis_colonne_inexistante' => 'គ្មានជួរឈរ @col@',
	'avis_erreur' => 'កំហុស ៖ មើល ​ខាងក្រោម',
	'avis_erreur_connexion' => 'កំហុស​ បញ្ជាប់',
	'avis_erreur_cookie' => 'បញ្ហា​ ខូកឃី',
	'avis_erreur_fonction_contexte' => 'កំហុស​ សរសេរ​កម្មវិធី។ មុខងារ​នេះ​ មិន​ត្រូវ​បាន​ហៅ​ក្នុង​បរិបទ​នេះ។',
	'avis_erreur_mysql' => 'កំហុស SQL',
	'avis_erreur_sauvegarde' => 'កំហុស​ រក្សាច្បាប់ចំលង (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'បញ្ហា​ ចូល​ទៅ​​តំបន់​ឯកជន',

	// B
	'barre_a_accent_grave' => 'បញ្ចូល​ អក្សរ A  ធំ មានសញ្ញា ` ពីលើ',
	'barre_aide' => 'ប្រើ​ប្រាស់ ផ្លូវកា​ត់រៀប​អក្សរ ​ដើម្បី​កែ​លំអ តំរៀបចំទំព័រ របស់អ្នក',
	'barre_e_accent_aigu' => 'បញ្ចូល ​អក្សរ E ធំ មានសញ្ញា ’ ពីលើ',
	'barre_eo' => 'បញ្ចូល​ ​អក្សរ E ក្នុង O (មានរាង oe)',
	'barre_eo_maj' => 'បញ្ចូល​ ​អក្សរ E ធំ ក្នុង O (មានរាង OE)',
	'barre_euro' => 'បញ្ចូល និមិត្ត​សញ្ញា €',
	'barre_gras' => 'ដាក់ជា អក្សរ {{​ដិត}}',
	'barre_guillemets' => 'ដាក់​ជា ម្ជុលបើកបិទ «  »',
	'barre_guillemets_simples' => 'ដាក់​ជា ម្ជុលបើកបិទ កំរិត ២  ',
	'barre_intertitre' => 'បំលែង ជា {{{អន្តរ​ចំណងជើង​}}}',
	'barre_italic' => 'ដាក់ជា {​អក្សរ ​ទ្រេត​}',
	'barre_lien' => 'បំលែង ជា [តំណភ្ជាប់ អិនរើណែត → http://...]',
	'barre_lien_input' => 'សូម​បង្ហាញ អាសយដ្ឋាន នៃតំណភ្ជាប់ របស់អ្នក (​អ្នកអាចបង្ហាញ មួយអាសយដ្ឋាន អិនរើណែត ជារាងរៅ http://www.mysite.com ឬ ​បង្ហាញ យ៉ាងសាមញ្ញ លេខសំគាល់អត្ថបទ នៃ សៃថ៍នេះ។',
	'barre_note' => 'បំលែង ជា [[កំណត់ចំណាំ​ នៅបាតទំព័រ]]',
	'barre_paragraphe' => 'បង្កើត មួយកថាខណ្ឌ',
	'barre_quote' => 'បរិយាយ មួយសារ </quote>', # MODIF
	'bouton_changer' => 'ផ្លាស់ប្តូរ',
	'bouton_chercher' => 'ស្វែងរក',
	'bouton_choisir' => 'ជ្រើសរើស',
	'bouton_download' => 'ទាញយក', # MODIF
	'bouton_enregistrer' => 'រក្សា​ទុក',
	'bouton_radio_desactiver_messagerie_interne' => 'អសកម្មភាព បញ្ញើ​សារ ខាងក្នុង',
	'bouton_radio_envoi_annonces' => 'ផ្ញើ​ ជំនូនដំណឹង ​នៃអ្នក​បោះ​ពុ​ម្ភ​ផ្សាយ',
	'bouton_radio_non_envoi_annonces' => 'មិនត្រូវ​ផ្ញើ​ ជំនូនដំណឹង​',
	'bouton_radio_non_envoi_liste_nouveautes' => 'មិន​ត្រូវ​ផ្ញើ​ បញ្ជី​ នៃភាពប្លែក',
	'bouton_recharger_page' => 'ផ្ទុកឡើងវិញ ​ទំព័រ​នេះ',
	'bouton_telecharger' => 'ទាញយក',
	'bouton_upload' => 'ទាញយក', # MODIF
	'bouton_valider' => 'ធ្វើអោយមាន សុពលភាព',

	// C
	'cal_apresmidi' => 'ល្ងាច (p.m.)',
	'cal_jour_entier' => 'ពេញ​ មួយ​ថៃ្ង',
	'cal_matin' => '​ព្រឹក (a.m.)',
	'cal_par_jour' => 'ប្រក្រតីទិន ​ប្រចាំ​ថៃ្ង',
	'cal_par_mois' => 'ប្រក្រតីទិន ​ប្រចាំខែ',
	'cal_par_semaine' => 'ប្រក្រតីទិន ​ប្រចាំ​ស​ប្ដា​ហ៍',
	'choix_couleur_interface' => 'ពណ៌',
	'choix_interface' => 'ជំរើស ផ្ទាំងប្រទាក់',
	'colonne' => 'ជួរឈរ',
	'confirm_changer_statut' => 'ប្រយ័ត្ន, អ្នក​បាន សួររកផ្លាស់​ប្ដូរ ​ស្ថានភាព នៃធាតុនេះ ។ ​អ្នក​ចង់ ​បន្ដ​​ ​ឬ?',
	'correcte' => 'ត្រឹមត្រូវ',

	// D
	'date_aujourdhui' => 'ថ្ងៃនេះ',
	'date_avant_jc' => 'មុន គ.ស.',
	'date_dans' => 'ក្នុង @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'ស្អែក',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_jour_heure' => '@jour@ វេលា @heure@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => '​ថ្ងៃ @nomjour@ @date@',
	'date_heures' => 'ម៉ោង',
	'date_hier' => 'ម្សិលមិញ',
	'date_il_y_a' => 'មាន @delai@',
	'date_jnum1' => 'ទី ១',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'ថ្ងៃអាទិត្យ',
	'date_jour_1_abbr' => 'អាទិ.',
	'date_jour_1_initiale' => 'អាទិ.',
	'date_jour_2' => 'ថ្ងៃ​ចន្ទ',
	'date_jour_2_abbr' => 'ច.',
	'date_jour_2_initiale' => 'ច.',
	'date_jour_3' => 'ថ្ងៃ​អង្គារ',
	'date_jour_3_abbr' => 'អ.',
	'date_jour_3_initiale' => 'អ.',
	'date_jour_4' => 'ថ្ងៃ​ពុធ',
	'date_jour_4_abbr' => 'ព.',
	'date_jour_4_initiale' => 'ព.',
	'date_jour_5' => 'ថ្ងៃ​ព្រហស្បតិ៍',
	'date_jour_5_abbr' => 'ព្រ.',
	'date_jour_5_initiale' => 'ព្រ.',
	'date_jour_6' => 'ថ្ងៃ​សុក្រ',
	'date_jour_6_abbr' => 'សុ.',
	'date_jour_6_initiale' => 'សុ.',
	'date_jour_7' => 'ថ្ងៃ​សៅរ៍',
	'date_jour_7_abbr' => 'សៅ.',
	'date_jour_7_initiale' => 'សៅ.',
	'date_jours' => 'ថៃ្ង',
	'date_minutes' => 'នាទី',
	'date_mois' => 'ខែ',
	'date_mois_1' => 'ខែ មក​រា',
	'date_mois_10' => 'ខែ តុលា',
	'date_mois_11' => 'ខែ វិច្ឆិកា',
	'date_mois_12' => 'ខែ ធ្នូ',
	'date_mois_2' => 'ខែ កុម្ភៈ',
	'date_mois_3' => 'ខែ មីនា',
	'date_mois_4' => 'ខែ មេ​សា',
	'date_mois_5' => 'ខែ ឧសភា',
	'date_mois_6' => 'ខែ មិថុនា',
	'date_mois_7' => 'ខែ កក្កដា',
	'date_mois_8' => 'ខែ សីហា',
	'date_mois_9' => 'ខែ កញ្ញា',
	'date_saison_1' => 'រដូវ រងា',
	'date_saison_2' => 'រដូវ ផ្ការីក',
	'date_saison_3' => 'រដូវ ក្ដៅ',
	'date_saison_4' => 'រដូវ​ ស្លឹកឈើ​ជ្រុះ',
	'date_secondes' => 'វិនាទី',
	'date_semaines' => 'ស​ប្ដា​ហ៍',
	'date_un_mois' => 'ខែ',
	'date_une_heure' => 'ម៉ោង',
	'date_une_minute' => 'នាទី',
	'date_une_seconde' => 'វិនាទី',
	'date_une_semaine' => 'សប្តាហ៍',
	'dirs_commencer' => ' ដើម្បី​ ផ្ដើម​ពិតប្រាកដ ការតំលើង',
	'dirs_preliminaire' => 'ជំហានដំបូង ៖ <b> តំរែតំរូវ សិទ្ធិចូលទៅ</b>',
	'dirs_probleme_droits' => 'បញ្ហា សិទ្ធិចូលទៅ',
	'dirs_repertoires_absents' => '<p><b> គ្មានរកឃើញ ថត​ឯកសារ ​ខាងក្រោម៖ </b></p><ul>@bad_dirs@.</ul> <p> វាអាច មក​ពី ​បញ្ហា ដាក់​តួអក្សរធំ ឬ​ ដាក់តួអក្សរតូច មិន​សម​ស្រប​ អោយ​ឈ្មោះ​ថត​ឯកសារ។
 សូម​ផ្ទៀងផ្ទាត់​តួអក្សរ​តូច និង តួអក្សរធំ ​នៃ​ថត​ឯកសារ​ទាំងនេះ ​អោយត្រូវតាម ​អ្វី​ដែល​ត្រូវ​បាន ​បង្ហាញចេញ។
 ខាងលើនេះ, បើ​មិន​ជាករណីនោះទេ, សូម​ប្ដូរ​ឡើងវិញ ឈ្មោះ​ថត​ឯកសារ ជាមួយផ្នែកទន់ នៃ FTP របស់​អ្នក ដើម្បី​កែតំរូវ​កំហុស </p>
 <p> ពេល​កែ​រួចរាល់​, អ្នកនឹង​អាច',
	'dirs_repertoires_suivants' => '<p><b> គ្មានអាចប្តូរឈ្មោះ ថត​ឯកសារ​ខាងក្រោម៖ </b></p><ul>@bad_dirs@</ul><p>
 ដើម្បីសង្គ្រោះវា, សូម​ប្រើ​ប្រាស់ ខំព្យូរើ​ភ្ញៀវ FTP របស់​អ្នក​ ដើម្បី​តំរែតំរូវ សិទ្ធិចូលទៅ មួយ នៃ ថតឯកសារ ទាំងនេះ។ បានពន្យល់លំអិត លំដាប់លំដោយ អនុវត្ត ក្នុងឯកសារណែនាំ វិធីតំលើង៖ </p>
 <p> ពេល រួចរាល់ទង្វើនេះ​, អ្នក​អាច',
	'double_occurrence' => 'ព្រឹត្តិការផ្ទួន នៃ @balise@',

	// E
	'en_cours' => 'កំពុងធ្វើការ',
	'envoi_via_le_site' => 'បញ្ញើ តាមវ៉ែបសៃថ៍',
	'erreur' => 'កំហុស ៖',
	'erreur_balise_non_fermee' => '​មិន​បានដាក់ ប្លាក​បិទ៖',
	'erreur_texte' => 'កំហុស',
	'etape' => 'ដំណាក់',

	// F
	'fichier_introuvable' => '​គ្មានរកឃើញ សំណុំឯកសារ ៖ @fichier@', # MODIF
	'form_deja_inscrit' => 'អ្នក​ធ្លាប់បាន​ហើយ ចុះ​ឈ្មោះ​។',
	'form_email_non_valide' => 'អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​អ្នក គ្មាន​សុពលភាព។',
	'form_forum_access_refuse' => 'អ្នក​គ្មានទៀត ​ចូល​ទៅសៃថ៍ នេះ ។',
	'form_forum_bonjour' => 'សួស្តី @nom@,',
	'form_forum_email_deja_enregistre' => 'អាសយដ្ឋាន​អ៊ីមែវល៍​នេះ​ ធ្លាប់ត្រូវបានចុះ​ឈ្មោះ​, ដូច្នោះ អ្នកអាចប្រើប្រាស់ ពាក្យសំងាត់ របស់អ្នក តាមទំលាប់។',
	'form_forum_identifiant_mail' => 'អត្តសញ្ញា​ថ្មី របស់អ្នក ទើបតែត្រូវបាន ផ្ញើទៅអ្នក តាម អ៊ីមែវល៍។',
	'form_forum_identifiants' => 'អត្តសញ្ញា​ផ្ទាល់ខ្លួន',
	'form_forum_indiquer_nom_email' => 'បង្ហាញនៅ​ទី​នេះ ​ឈ្មោះ និង​អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​អ្នក។ អត្ត​សញ្ញា​ផ្ទាល់ខ្លួន​ របស់​អ្នក ​នឹងទៅដល់អ្នក យ៉ាងរហ័ស ​តាម​​អ៊ីមែវល៍។',
	'form_forum_login' => 'ពិនិត្យចូល៖',
	'form_forum_message_auto' => '(​នេះ​ ជា​ មួយសារ​ស្វ័យប្រវត្ដិ​)',
	'form_forum_pass' => 'ពាក្យសំងាត់៖',
	'form_forum_probleme_mail' => 'បញ្ហា​មែវ​ល៍ ៖ មិនបាផ្ញើ អត្តសញ្ញា្។',
	'form_forum_voici1' => 'នេះ​ជា អត្ត​សញ្ញា របស់​អ្នក ដើម្បី​អាចចូលរួម ទៅអាយុកាល​ នៃវ៉ែបសៃថ៍ "@nom_site_spip@" (@adresse_site@)៖',
	'form_forum_voici2' => 'នេះ​ជា​ អត្តសញ្ញា​ របស់​អ្នក ​ដើម្បី​ស្នើអត្ថបទ លើវ៉ែបសៃថ៍ "@nom_site_spip@" (@adresse_login@)៖',
	'form_indiquer_email' => 'សូម​បង្ហាញ ​អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​អ្នក។',
	'form_indiquer_nom' => 'សូមបង្ហាញ​ឈ្មោះ ​របស់​អ្នក។',
	'form_indiquer_nom_site' => 'សូមបង្ហាញ​ឈ្មោះ​វ៉ែបសៃថ៍ របស់​អ្នក។',
	'form_pet_deja_enregistre' => 'វ៉ែបសៃថ៍នេះ​ ធ្លាប់ត្រូវបាន​ចុះបញ្ជី​។',
	'form_pet_signature_pasprise' => 'ហត្ថលេខា ​របស់​អ្នក ត្រូវ​បាន​បដិសេធ ។',
	'form_prop_confirmer_envoi' => 'បញ្ជាក់​ទទួលស្គាល់ បញ្ញើ',
	'form_prop_description' => 'ការពិពណ៌នា/វិចារ',
	'form_prop_enregistre' => 'បានចុះបញ្ជី សំណើរ​ របស់​អ្នក​, វា​នឹង​លេច​ចេញ ​លើ​អិនរើណែត បន្ទាប់ពីមាន​សុពលភាព ​ដោយ​អ្នកអភិបាលវ៉ែបសៃថ៍នេះ។', # MODIF
	'form_prop_envoyer' => 'ផ្ញើ​ មួយសារ',
	'form_prop_indiquer_email' => 'សូម​បញ្ចូល​ មួយអាសយដ្ឋាន​អ៊ីមែវល៍​ ដែល​មាន​សុពលភាព ។',
	'form_prop_indiquer_nom_site' => 'សូម​បញ្ចូល​ឈ្មោះ​ របស់​វ៉ែបសៃថ៍។',
	'form_prop_indiquer_sujet' => 'សូម​បញ្ចូល​ មួយប្រធានបទ',
	'form_prop_message_envoye' => 'បានផ្ញើ សារ',
	'form_prop_non_enregistre' => 'គ្មានបានចុះបញ្ជី សំណើ ​របស់​អ្នក។',
	'form_prop_sujet' => 'ប្រធានបទ',
	'form_prop_url_site' => 'អាសយដ្ឋាន URL នៃវ៉ែបសៃថ៍', # MODIF
	'forum_non_inscrit' => '​អ្នកគ្មានបាន​ចុះ​ឈ្មោះ, ឬ ​អាសយដ្ឋាន ឬ ពាក្យសំងាត់ ខុស​។',
	'forum_par_auteur' => 'ដោយ @auteur@',
	'forum_titre_erreur' => 'កំហុស​...',

	// I
	'ical_texte_rss_articles' => 'ថតឯកសារ "ចុងទំព័រ" នៃអត្ថបទ របស់សៃថ៍នេះ ថិតនៅ អាសយដ្ឋាន៖',
	'ical_texte_rss_articles2' => 'អ្នក​ក៏​អាច ទទួលបាន​ឯកសារ "ចុងទំព័រ" សំរាប់អត្ថបទ នៃមាតិកានីមួយៗ របសវ៉ែបសៃថ៍៖',
	'ical_texte_rss_breves' => 'លើសពីហ្នឹង, វាមាន មួយឯកសារ ​ដែល​មានផ្ទុកសង្ខេបពត៌មាន ​របស់​វ៉ែបសៃថ៍។ ដោយ​បញ្ជាក់លេខសំគាល់ នៃមាតិកា, អ្នកនឹងទទួលបាន ត្រឹមសង្ខេបនានា នៃមាតិកានេះ។',
	'icone_a_suivre' => 'នៅមាន បន្ត',
	'icone_admin_site' => 'អ្នកអភិបាលសៃថ៍',
	'icone_agenda' => 'សៀវភៅកត់ត្រា',
	'icone_aide_ligne' => 'ជំនួយ',
	'icone_articles' => 'អត្ថបទ',
	'icone_auteurs' => 'អ្នកនិពន្ធ',
	'icone_brouteur' => 'ការត្រាច់រក រហ័ស',
	'icone_configuration_site' => 'ការកំណត់ទំរង់',
	'icone_configurer_site' => 'ការកំណត់ទំរង់ វ៉ែបសៃថ៍ របស់​អ្នក',
	'icone_creer_nouvel_auteur' => 'បង្កើត មួយ​អ្នកនិពន្ធ​ថ្មី',
	'icone_creer_rubrique' => 'បង្កើត មួយមាតិកា',
	'icone_creer_sous_rubrique' => 'បង្កើត​ មួយអនុ​មាតិកា',
	'icone_deconnecter' => 'ពិនិត្យចេញ',
	'icone_discussions' => 'ការ​ពិភាក្សា',
	'icone_doc_rubrique' => 'ឯកសារ​ នៃមាតិកា',
	'icone_ecrire_article' => 'សរសេរ មួយ​អត្ថបទ​ថ្មី',
	'icone_edition_site' => 'កំណែសំរួល',
	'icone_gestion_langues' => 'ការ​គ្រប់គ្រង​ ភាសា',
	'icone_informations_personnelles' => 'ពត៌មាន​ផ្ទាល់ខ្លួន',
	'icone_interface_complet' => 'ផ្ទាំង​ប្រទាក់​ ពេញ',
	'icone_interface_simple' => 'ផ្ទាំងប្រទាក់ ​ត្រូវបានសាមញ',
	'icone_maintenance_site' => 'តំហែទាំ​វ៉ែបសៃថ៍',
	'icone_messagerie_personnelle' => 'បញ្ញើសារ​ផ្ទាល់ខ្លួន',
	'icone_repartition_debut' => 'បង្ហាញ​ បំណែងចែក ពី​ដំបូង',
	'icone_rubriques' => 'មាតិកា',
	'icone_sauver_site' => 'កាបង្កើត ច្បាប់ចំលង នៃវ៉ែបសៃថ៍',
	'icone_site_entier' => 'វ៉ែបសៃថ៍ ​ទាំងមូល',
	'icone_sites_references' => 'វ៉ែបសៃថ៍ យោង',
	'icone_statistiques' => 'ស្ថិតិ​វ៉ែបសៃថ៍',
	'icone_suivi_activite' => 'តាមដាន អាយុកាល ​នៃវ៉ែបសៃថ៍',
	'icone_suivi_actualite' => 'ការវិវត្ត នៃវ៉ែបសៃថ៍',
	'icone_suivi_pettions' => 'តាមដាន/គ្រប់គ្រង ​បណ្តឹងជំទាស់',
	'icone_suivi_revisions' => 'កំណែប្រែ នៃអត្ថបទ',
	'icone_supprimer_document' => 'លុប​ចេញ ឯកសារ​នេះ',
	'icone_supprimer_image' => 'លុបចេញ ​រូបភាព​នេះ',
	'icone_tous_articles' => 'គ្រប់អត្ថបទ ​របស់​អ្នក',
	'icone_tous_auteur' => 'គ្រប់ អ្នកនិពន្ធ​',
	'icone_visiter_site' => 'ទស្សនា', # MODIF
	'icone_voir_en_ligne' => '​មើល​ លើអិនរើណែត',
	'img_indisponible' => 'គ្មាន​រូបភាព',
	'impossible' => 'មិន​អាចទៅរួច',
	'info_a_suivre' => 'នៅមាន បន្ត →',
	'info_acces_interdit' => 'ការ​ចូលទៅ ​ត្រូវ​បាន​ហាម',
	'info_acces_refuse' => 'ការ​ចូល​ទៅ ត្រូវ​បាន​បដិសេធ',
	'info_action' => 'សកម្មភាព ៖ @action@',
	'info_administrer_rubriques' => 'អ្នក​អាច អភិបាល មាតិកា​នេះ និង មាតិការង របស់​វា',
	'info_adresse_non_indiquee' => 'អ្នក​មិន​បានបង្ហាញ អាសយដ្ឋាន​ ​ត្រូវ​សាកល្បង !',
	'info_aide' => 'ជំនួយ ៖',
	'info_ajouter_mot' => 'បន្ថែម​ មួយពាក្យ​នេះ',
	'info_annonce' => 'សេចក្ដី​ប្រកាស',
	'info_annonces_generales' => 'ការប្រកាសដំណឹង ​ទូទៅ ៖',
	'info_article_propose' => 'អត្ថបទ​ ត្រូវ​បាន​ដាក់​ស្នើ',
	'info_article_publie' => 'បានផ្សព្វផ្សាយ អត្ថបទ​',
	'info_article_redaction' => 'អត្ថបទ ​កំពុង​ ក្នុងការ​តែង',
	'info_article_refuse' => 'អត្ថបទ​ ត្រូវ​បាន​បដិសេធ',
	'info_article_supprime' => 'អត្ថបទ​ ត្រូវ​បាន​លុបចេញ',
	'info_articles' => 'អត្ថបទ',
	'info_articles_a_valider' => 'អត្ថបទ​ ​ត្រូវធ្វើ​អោយ​​សុពលភាព',
	'info_articles_proposes' => 'អត្ថបទ ​ត្រូវ​បាន​ស្នើ',
	'info_auteurs_nombre' => 'អ្នកនិពន្ធ ៖',
	'info_authentification_ftp' => 'ធ្វើអោយត្រឹមត្រូវ តាមភាពដើម (​ដោយ FTP)។',
	'info_breves_2' => 'ពត៌មានសង្ខេប',
	'info_connexion_refusee' => 'បញ្ជាប់ ​ត្រូវ​បាន​បដិសេធ',
	'info_contact_developpeur' => '​ទាក់ទង​ អ្នក​អភិវឌ្ឍ។', # MODIF
	'info_contenance' => 'វ៉ែបសៃថ៍ នេះ​មានផ្ទុក ៖',
	'info_contribution' => 'ការ​រួមចំណែក នៃ​វេទិកា', # MODIF
	'info_copyright' => '@spip@ ជា​ផ្នែកទន់សេរី ត្រូវបានបែងចែក ​ដោយ @lien_gpl@។',
	'info_copyright_doc' => 'សំរាប់ ពត៌មាន​បន្ថែម, ​មើលសៃថ៍ <a href="@spipnet@">http://www.spip.net/en</a>។', # MODIF
	'info_copyright_gpl' => 'តាមអាជ្ញាបណ្ណ GPL',
	'info_cours_edition' => 'អត្ថបទ​ របស់​អ្នក ​កំពុង ​ត្រូវតែង', # MODIF
	'info_creer_repertoire' => 'សូម​បង្កើត មួយ​ឯកសារ ឬ មួយ​បញ្ជី​រាយ​នាម ដែលបានដាក់ឈ្មោះ​៖',
	'info_creer_repertoire_2' => '​ខាងក្នុង​បញ្ជី​រាយ​នាម​រង <b>@repertoire@</b>, រួច៖',
	'info_creer_vignette' => 'ការ​បង្កើត​​ស្វ័យប្រវត្ដិ​ នៃ​គំនូស​ព្រាង',
	'info_deplier' => 'លាចេញ',
	'info_descriptif_nombre' => 'ជា ការពិពណ៌នា៖',
	'info_description' => 'ការពិពណ៌នា ៖',
	'info_description_2' => 'ការពិពណ៌នា ៖',
	'info_dimension' => 'ខ្នាត ៖',
	'info_ecire_message_prive' => 'សរសេរ​ សារ​ឯកជន',
	'info_email_invalide' => 'អាសយដ្ឋាន​អ៊ីមែវល៍​ គ្មាន​សុពលភាព។',
	'info_en_cours_validation' => 'អត្ថបទ​ របស់​អ្នក ​កំពុង​ ត្រូវបានតែង',
	'info_en_ligne' => 'បច្ចុប្បន្ន ​កំពុងលើ​អិនរើណែត ៖',
	'info_envoyer_message_prive' => 'ផ្ញើ​ មួយសារ​ឯកជន ​ទៅ​អ្នកនិពន្ធ​នេះ',
	'info_erreur_requete' => 'កំហុស​ ក្នុង​សំណួរអង្កេត៖',
	'info_erreur_squelette2' => 'គ្មាន​គំរូ <b>@fichier@</b> ទំនេរ...',
	'info_erreur_systeme' => 'កំហុស​ប្រព័ន្ធ (errno @errsys@)',
	'info_erreur_systeme2' => 'ថាស​រឹង (hard disk) ប្រហែលជា​ពេញ ឬ មូលដ្ឋានទិន្នន័យ​ខូច ។ <br /> 
<span style="color:red;">ព្យាយាម <a href=\'@script@\'>​ជួសជុល​ឃ្លាំង​ទិន្នន័យ </a>, ឬ​ទាក់ទង​អ្នក​ផ្ដល់​សេវាកម្ម​ របស់​អ្នក ។ </span>',
	'info_fini' => 'រួចរាល់ !',
	'info_format_image' => 'ទំរង់​រូបភាព អាចត្រូវបាន​ប្រើ​ប្រាស់ សំរាប់ការ​បង្កើត​កូនរូបភាព ៖ @gd_formats@។',
	'info_format_non_defini' => 'ទ្រង់ទ្រាយ ​គ្មានបានកំណត់',
	'info_grand_ecran' => 'បង្ហាញ​ស្គ្រីនធំ',
	'info_image_aide' => 'ជំនួយ',
	'info_image_process_titre' => 'វិធី​បង្កើត ​កូនរូបភាព',
	'info_impossible_lire_page' => '<b>​កំហុស​!</b> គ្មានអាចអានទំព័រ<tt><html>@test_proxy@</html></tt> ​តាម​ខំព្យូរើបំរើសេវា Proxy',
	'info_installation_systeme_publication' => 'ការ​តំលើង ​ប្រ​ព័ន្ធផ្សព្វផ្សាយ​...',
	'info_installer_documents' => 'អ្នក​អាចតំលើង ​ស្វ័យប្រវត្ដិ​ គ្រប់ឯកសារ ដែល​មានផ្ទុក ​ក្នុង​ថត​ឯកសារ​@upload@។',
	'info_installer_ftp' => 'ក្នុង​នាម​ជា ​អ្នកអភិបាល, អ្នក​អាចតំលើង (​តាមខំព្យូរើបំរើសេវា FTP) សំណុំឯកសារ ​ក្នុង​ថត​ឯកសារ @upload@ ដើម្បី​បន្ត ជ្រើសយកដោយផ្ទាល់ ពួកវា នៅទីនេះ។', # MODIF
	'info_installer_images' => 'អ្នក​អាច​តំលើង រូបភាព​ មានទ្រង់ទ្រាយ .JPEG, .GIF និង .PNG។',
	'info_installer_images_dossier' => 'តំលើង​រូបភាព ​ក្នុង​ថត​ឯកសារ @upload@ ដើម្បី​អាច​ជ្រើសយកពួកវា នៅទី​នេះ។',
	'info_interface_complete' => 'ផ្ទាំង​ប្រទាក់ ​ពេញលេញ',
	'info_interface_simple' => 'ផ្ទាំង​ប្រទាក់​ ត្រូវបានសាមញ្ញ',
	'info_joindre_document_article' => 'អ្នក​អាច​ភ្ជាប់​ ទៅ​អត្ថបទ​នេះ ឯកសារប្រភេទ',
	'info_joindre_document_rubrique' => 'អ្នក​អាច​បន្ថែម ក្នុ​ងមាតិកានេះ ឯកសារប្រភេទ',
	'info_joindre_documents_article' => 'អ្នក​អាច​ភ្ជាប់​ ទៅ​អត្ថបទនេះ ឯកសារប្រភេទ ៖',
	'info_l_article' => 'អត្ថបទ',
	'info_la_breve' => 'ពត៌មានសង្ខេប',
	'info_la_rubrique' => 'មាតិកា',
	'info_langue_principale' => 'ភាសាបថម នៃវ៉ែបសៃថ៍',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'ដោយ @les_auteurs@',
	'info_logo_format_interdit' => 'អនុញ្ញ្តាតិ ត្រឹម​តែ​រូប​សញ្ញា​ មានទ្រង់ទ្រាយ @formats@ ។',
	'info_logo_max_poids' => 'រូប​សញ្ញា​ ត្រូវ​តែ​តិច​ជាង @maxi@ (សំណុំឯកសារនេះមាន @actuel@)។',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'សារ',
	'info_message_supprime' => 'បានលុបចេញ សារ​',
	'info_mise_en_ligne' => 'ថ្ងៃខែឆ្នាំ បានផ្សព្វផ្សាយ លើអិនរើណែត ៖',
	'info_modification_parametres_securite' => 'កែប្រែ ការកំណត់សុវត្ថភាព',
	'info_mois_courant' => 'ក្នុង​អំឡុង​ នៃខែ ៖',
	'info_mot_cle_ajoute' => 'បានបន្ថែម ពាក្យ​គន្លឹះ ​ខាងក្រោម​ ទៅ',
	'info_multi_herit' => 'ភាសា​ លំនាំដើម',
	'info_multi_langues_soulignees' => '<u>​ភាសា​ ដែល​បាន​គូរ​បន្ទាត់​ក្រោម​</u> ទទួលបានបំណកប្រែ​ គ្រប់អត្ថបទ នៃផ្ទាំង​ប្រទាក់។ បើ​អ្នក​ជ្រើស​យក ​ភាសា​ទាំងនេះ, មាន​ច្រើនធាតុ ​នៃ​សៃថ៍សាធារណះ (​ថ្ងៃខែឆ្នាំ, បែបបទ​) នឹង​ត្រូវបាន​ប្រែ​សំរួល​ស្វ័យប្រវត្ដិ ។ ចំពោះ​ភាសា​ គ្មានគូសបន្ទាត់ក្រោម, ធាតុ​ទាំងនោះ​ នឹង​លេច​ចេញ​ជា​ភាសាលំនាំដើម ​នៃ​សៃថ៍។', # MODIF
	'info_multilinguisme' => '​ពហុ​ភាសា',
	'info_nom_non_utilisateurs_connectes' => 'ឈ្មោះ​របស់​អ្នក​ មិន​លេច​ចេញ ​ក្នុង​បញ្ជី​អ្នក​ប្រើ​ប្រាស់​ ដែល​បាន​ភ្ជាប់ ។', # MODIF
	'info_nom_utilisateurs_connectes' => 'ឈ្មោះ​របស់​អ្នក​ លេច​ចេញ​ ​ក្នុង​បញ្ជី​អ្នក​ប្រើប្រាស់​ដែល​បាន​​ភ្ជាប់។', # MODIF
	'info_nombre_en_ligne' => 'បច្ចុប្បន្ន កំពុងលើអិនរើណែត ៖',
	'info_non_resultat' => 'គ្មាន​លទ្ធផល​ សំរាប់ "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'អ្នក​មិន​​ប្រើប្រាស់​ បញ្ញើ​សារ​ ខាង​ក្នុងវ៉ែបសៃថ៍ នេះ​។',
	'info_nouveau_message' => 'អ្នកមាន​ មួយសារ​ថ្មី',
	'info_nouveaux_messages' => 'អ្នកមាន @total_messages@ សារ​ថ្មី',
	'info_numero_abbreviation' => 'លេខ ',
	'info_obligatoire' => 'ពត៌មាននេះ តំរូវអោយមាន',
	'info_pense_bete' => 'រំលឹក',
	'info_petit_ecran' => 'កូនស្គ្រីន',
	'info_petition_close' => 'បិទ បណ្តឹងជំទាស់',
	'info_pixels' => 'ធាតុរូបភព',
	'info_plusieurs_mots_trouves' => 'បានរកឃើញ ច្រើនពាក្យ​គន្លឹះ​ សំរាប់ \\"@cherche_mot@\\":',
	'info_portfolio_automatique' => 'ផលប័ត្រ​ស្វ័យប្រវត្ដិ',
	'info_premier_resultat' => '[@debut_limit@​លទ្ធិ​ផល​ដំបូង លើ @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ លទ្ធិ​ផល​ដំបូង​ លើ @total@]',
	'info_propose_1' => '[@nom_site_spip@] ស្នើ៖ @titre@',
	'info_propose_2' => 'អត្ថបទ​ ដែល​ត្រូវបានស្នើ------------------​',
	'info_propose_3' => 'បានស្នើ អត្ថបទ  "@titre@" សំរាប់ការផ្សព្វផ្សាយ។',
	'info_propose_4' => 'អ្នក​ត្រូវ​បាន​អញ្ជើញ​ មក​ពិនិត្យឡើងវិញ វា និង​ មកផ្ដល់​មតិ​ របស់​អ្នក',
	'info_propose_5' => 'ក្នុង​វេទិកា បាន​ភ្ជាប់​ជាមួយវា។ វា​មានស្រាប់ នៅ​អាសយដ្ឋាន ៖',
	'info_publie_01' => 'បានធ្វើអោយសុពលភាព អត្ថបទ  "@titre@" ត្រូវ​​ដោយ @connect_nom@។',
	'info_publie_1' => '[@nom_site_spip@] បាន​ផ្សព្វផ្សាយ​: @titre@',
	'info_publie_2' => 'អត្ថបទ​ ត្រូវ​បាន​ផ្សព្វផ្សាយ
',
	'info_rechercher' => 'ស្វែងរក',
	'info_rechercher_02' => 'ស្វែងរក ៖',
	'info_remplacer_vignette' => 'ជំនួស កូន​រូបភាព លំនាំដើម ដោយ​រូប​សញ្ញា ​ដែល​បានបង្កើត​ខ្លួនឯង ៖',
	'info_sans_titre_2' => 'គ្មាន​ចំណងជើង',
	'info_selectionner_fichier' => 'អ្នក​អាច​ជ្រើសយក មួយសំណុំឯកសារ នៃថតឯកសារ @upload@',
	'info_selectionner_fichier_2' => 'ជ្រើសយក មួយឯកសារ ៖',
	'info_supprimer_vignette' => 'លុប​ចេញ កូនរូបភាព',
	'info_symbole_bleu' => 'A <b>​និមិត្ដសញា​</b> ពណ៌​ខៀវ<b>​ ​បង្ហាញការរំលឹក</b>៖ មានន័យថា មួយសារសំរាប់​បំរើប្រាស់​ផ្ទាល់ខ្លួន​ របស់​អ្នក ។',
	'info_symbole_jaune' => 'A <b>​និមិត្ដសញា​</b> ពណ៌​លឿង​<b>​បង្ហាញ មួយជំនូនដំណឹង​ ទៅគ្រប់អ្នកតែងអត្ថបទ </b>៖ ​អាចកែប្រែ ដោយគ្រប់អ្នកអភិបាល, និង អាចឃើញ ដោយគ្រប់អ្នកតែងអត្ថបទ។', # MODIF
	'info_symbole_vert' => '​និមិត្ដសញា​<b>ពណ៌​បៃតង​</b> បង្ហាញ <b>បណ្តូរសារ ជាមួយ​អ្នកប្រើប្រាស់ដទៃ</b> នៃវ៉ែបសៃថ៍។', # MODIF
	'info_telecharger_nouveau_logo' => 'ផ្ទុក​ឡើង​ មួយរូប​សញ្ញា​ថ្មី ៖',
	'info_telecharger_ordinateur' => 'ផ្ទុក​ឡើង​ ពីខំព្យូរើ របស់​អ្នក ៖',
	'info_tous_resultats_enregistres' => '[​គ្រប់លទ្ធផល ត្រូវ​បាន​រក្សាទុក]',
	'info_tout_afficher' => 'បង្ហាញ​ចេញ ទាំងអស់',
	'info_travaux_texte' => 'វ៉ែបសៃថ៍នេះ​ មិន​ទាន់​ត្រូវបានកំណត់ទំរង់។ ត្រលប់មកវិញ ពេលក្រោយ...',
	'info_travaux_titre' => 'វ៉ែបសៃថ៍ កំពុង​ត្រូវបង្កើត',
	'info_trop_resultat' => 'លទ្ធផល​ ច្រើន​ពេក សំរាប់ "@cherche_mot@"; សូម​សំរាំង ការ​ស្វែងរក។',
	'info_utilisation_messagerie_interne' => 'អ្នក​​ប្រើ​ប្រាស់ សេវាកម្មអ៊ីមែវល៍​ ខាងក្នុង នៃវ៉ែបសៃថ៍ នេះ។',
	'info_valider_lien' => 'ធ្វើ​អោយសុពលភាព តំណភ្ជាប់នេះ',
	'info_verifier_image' => ',សូម​ផ្ទៀផ្ទាត់ ថារូបភាព របស់អ្នក ត្រូវបានផ្ទេរ ដោយត្រឹមត្រូវ។',
	'info_vignette_defaut' => 'កូនរូបភាព លំនាំដើម',
	'info_vignette_personnalisee' => 'កូនរូបភាព តាមជំរើសផ្ទាល់',
	'info_visite' => 'ទស្សនា ៖',
	'info_vos_rendez_vous' => 'ការ​ណាត់ជួប របស់អ្នក ក្នុងពេលខាងមុខ',
	'infos_vos_pense_bete' => 'ការក្រើនរំលឹក ​របស់​អ្នក', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'បង្ហាញ​តែ​រូបតំណាង​ប៉ុណ្ណោះ',
	'lien_afficher_texte_icones' => 'បង្ហាញចេញ ​រូបតំណាង និង​អត្ថបទ',
	'lien_afficher_texte_seul' => 'បង្ហាញ​តែ​ អត្ថបទ',
	'lien_liberer' => 'រំដោះ',
	'lien_liberer_tous' => 'រំដោះ​អត្ថបទ​ទាំងនេះ', # MODIF
	'lien_nouvea_pense_bete' => 'ការក្រើនរំលឹក​ថ្មី',
	'lien_nouveau_message' => 'សារ​ថ្មី',
	'lien_nouvelle_annonce' => 'សេចក្ដីជូនដំណឹង​ថ្មី',
	'lien_petitions' => 'បណ្តឹងជំទាស់',
	'lien_popularite' => 'ប្រជាប្រិយភាព ៖ @popularite@%',
	'lien_racine_site' => 'ឫស នៃវ៉ែបសៃថ៍',
	'lien_reessayer' => 'ព្យាយាម​ឡើងវិញ',
	'lien_repondre_message' => 'ឆ្លើយ​ទៅ ​សារ​នេះ',
	'lien_supprimer' => 'លុប​ចេញ',
	'lien_tout_afficher' => 'បង្ហាញ​ចេញ ទាំងអស់',
	'lien_visite_site' => 'ចូលមើល វ៉ែបសៃថ៍',
	'lien_visites' => '@visites@ ទស្សនា',
	'lien_voir_auteur' => 'មើល​ អ្នកនិពន្ធ​នេះ',
	'ligne' => 'បណ្ដាញ',
	'login' => 'ភ្ជាប់',
	'login_acces_prive' => 'ការ​ចូល​ទៅ​ ទីឯកជន',
	'login_autre_identifiant' => 'ភ្ជាប់ ដោយប្រើប្រាស់ អត្តសញ្ញាដទៃ',
	'login_cookie_accepte' => 'សូមតំរែតំរូវ ឧបកររាវរក​របស់​អ្នក ​ដើម្បី​ព្រមទទួល (​យ៉ាង​ហោច​ណាស់​ សំរាប់វ៉ែបសៃថ៍ ​នេះ​)។',
	'login_cookie_oblige' => 'ដើម្បីសំគាល់ អត្ដសញា របស់​អ្នក ដោយ​ពិតប្រាកដ លើសៃថ៍នេះ, អ្នក​ត្រូវ​តែព្រម​ទទួល ​ខូ​កឃី។',
	'login_deconnexion_ok' => 'បានពិនិត្យចេញ។',
	'login_erreur_pass' => 'កំហុស​ ពាក្យសំងាត់។',
	'login_espace_prive' => 'ទីឯកជន',
	'login_identifiant_inconnu' => 'មិន​ស្គាល់​ អត្តសញ្ញា​"@login@"។',
	'login_login' => 'ពិនិត្យចូល ៖',
	'login_login2' => 'ពិនិត្យចូល (​អត្តសញ្ញា​ សំរាប់ភ្ជាប់ទៅ​ វ៉ែបសៃថ៍) ៖', # MODIF
	'login_login_pass_incorrect' => '(ការ​ពិនិត្យ​ចូល ឬ ​ពាក្យសំងាត់ មិន​ត្រឹមត្រូវ។​)',
	'login_motpasseoublie' => 'ភ្លេច​ ពាក្យសំងាត់ ឬ?',
	'login_non_securise' => 'ប្រយ័ត្ន, បែបបទនេះ គ្មានសុវត្ថភាព។ បើ​អ្នក​មិនចង់ ពាក្យសំងាត់ ​របស់​អ្នក ត្រូវ​បានស្ទាក់ លើបណ្តាញ, សូមសកម្ម ចាវ៉ាស្គ្រិប ក្នុងឿបកររាវរក របស់អ្នក និង',
	'login_nouvelle_tentative' => 'ការ​ព្យាយាម ​ថ្មី',
	'login_par_ici' => 'អ្នក​ត្រូវ​បាន​ចុះ​ឈ្មោះ​... តាម​នេះ​....',
	'login_pass2' => 'ពាក្យសំងាត់ ៖',
	'login_preferez_refuser' => '<b>បើ​អ្នក​ចង់​បដិសេធ​ខូ​កឃី</b>, មានមួយ​វិធី​ដទៃ សំរាប់ភ្ជាប់ (មិនសូវសុវត្ថភាព) រង់ចាំអ្នក ៖',
	'login_recharger' => 'ផ្ទុកឡើងវិញ ទំព័រ​នេះ',
	'login_rester_identifie' => 'រង់ចាំ ការសំគាល់អត្តសញ្ញា ប៉ុន្មានថ្ងៃទៀត', # MODIF
	'login_retour_public' => 'ត្រលប់ទៅ វ៉ែបសៃថ៍ សាធារណៈ',
	'login_retour_site' => 'ត្រលប់ទៅ វ៉ែបសៃថ៍ សាធារណៈ',
	'login_retoursitepublic' => 'ត្រលប់ទៅ វ៉ែបសៃថ៍ សាធារណៈ',
	'login_sinscrire' => 'ចុះ​ឈ្មោះ', # MODIF
	'login_test_navigateur' => 'សា​ល្បង​ឧបកររាវរក​/​​ភ្ជាប់​ឡើង​វិញ',
	'login_verifiez_navigateur' => '(ផ្ទៀងផ្ទាត់​ គ្រប់ពេល ដែលឧបកររាវរក របស់អ្នក មិនបាន​ចង​ចាំ ពាក្យសំងាត់ របស់​អ្នក...)',

	// M
	'masquer_colonne' => 'បិទបាំង ជួរឈរ នេះ',
	'masquer_trad' => 'បិទបាំង អត្ថបទប្រែសំរួល',
	'module_fichiers_langues' => 'សំណុំឯកសារ​ ភាសា',

	// N
	'navigateur_pas_redirige' => 'បើ​ឧបកររាវរក ​របស់​អ្នក ​មិន​ត្រូវ​បាន​ប្ដូរ​ទិស, ​ចុច​ទី​នេះ​ដើម្បី​បន្ដ។',
	'numero' => 'លេខ',

	// O
	'occurence' => 'ភាពកើតមាន',
	'onglet_affacer_base' => 'លុប​ចោល ​ឃ្លាំង​ទិន្នន័យ',
	'onglet_auteur' => 'អ្នកនិពន្ធ',
	'onglet_contenu_site' => 'ខ្លឹមសារ របស់វ៉ែបសៃថ៍',
	'onglet_evolution_visite_mod' => 'ការវិវត្ត',
	'onglet_fonctions_avances' => 'មុខងារ កំរិតខ្ពស់',
	'onglet_informations_personnelles' => 'ពត៌មាន​ផ្ទាល់ខ្លួន',
	'onglet_interactivite' => 'អន្ដរកម្ម',
	'onglet_messagerie' => 'បញ្ញើសារ',
	'onglet_repartition_rubrique' => 'បំណែងចែក តាមមាតិកា',
	'onglet_save_restaur_base' => 'បង្កើតច្បាប់ចំលង/​ធ្វើអោយដូចដើម ឃ្លាំង​ទិន្នន័យ',
	'onglet_vider_cache' => 'ធ្វើ​អោយ​ឃ្លាំង​សម្ងាត់​ទទេរ',

	// P
	'pass_choix_pass' => 'ជ្រើសរើស​ ពាក្យសំងាត់​ថ្មី​ របស់​អ្នក៖',
	'pass_erreur' => 'កំហុស',
	'pass_erreur_acces_refuse' => '<b>​កំហុស ៖</b> អ្នក​មិន​ចូល​ទៀត ទៅវ៉ែបសៃថ៍នេះ។',
	'pass_erreur_code_inconnu' => '<b>​កំហុស ៖</b> អក្សរ​កូដ​នេះ​ មិន​ត្រូវ​នឹង​អ្នក​ទស្សនា​ណាមួយ ​ដែល​មានសិទ្ធិចូលទៅ វ៉ែបសៃថ៍នេះ។', # MODIF
	'pass_erreur_non_enregistre' => '<b>​កំហុស ៖</b> អាសយដ្ឋាន <tt>@email_oubli@</tt> មិន​ត្រូវ​បាន​ចុះ​ឈ្មោះ​លើវ៉ែបសៃថ៍នេះ​។',
	'pass_erreur_non_valide' => '<b>​កំហុស ៖</b> អ៊ីមែវល៍នេះ<tt>@email_oubli@</tt> គ្មានសុពលភាព!',
	'pass_erreur_probleme_technique' => '<b>​កំហុសបច្ចេកទេស ៖</b> មិន​អាច​ផ្ញើ​ អ៊ីមែវល៍​នេះ​។',
	'pass_espace_prive_bla' => 'ទី​ឯកជន ​នៃ​វ៉ែបសៃថ៍នេះ​ ត្រូវចំហ សំរាប់អ្នក​ទស្សនា​, បន្ទាប់ពី​ចុះ​ឈ្មោះ​។ ពេល​បាន​ចុះ​ឈ្មោះ​រួច, អ្នកអាចពិនិត្យមើល អត្ថបទ ដែលកំពុងត្រូវបានតែង, ស្នើអត្ថបទ និង ចូលរួម ទៅគ្រប់វេទិកា។', # MODIF
	'pass_forum_bla' => 'អ្នក​បានសួររក ដើម្បីអន្តរាគម លើមួយវេទិកា ដែលទុកសំរាប់ អ្នកទស្សនាបានចំឈ្មោះ។', # MODIF
	'pass_indiquez_cidessous' => 'បញ្ចូល​ខាងក្រោម​ អាសយដ្ឋាន​អ៊ីមែវល៍​ ដែល​អ្នក​បាន​ចុះ​ឈ្មោះ​ពី​មុន។ អ្នក​នឹង​ទទួល​បាន មួយ​អ៊ីមែវល៍ ​ដែល​ពន្យល់​វិធី​ ដើម្បីសង្គ្រោះការចូលទៅ របស់អ្នក។',
	'pass_mail_passcookie' => '(​នេះ​ជា មួយ​សារ​ស្វ័យប្រវត្ដិ​)
 ដើម្បីរកមើល ការចូលទៅ របស់អ្នក ក្នុងវ៉ែបសៃថ៍ @nom_site_spip@ (@adresse_site@)
 សូម​ទៅ​អាសយដ្ឋាន បន្តបន្ទាប់៖ 
 @sendcookie@ 

ពេលនោះ អ្នកនឹងអាច បញ្ចូល មួយពាក្យសំងាត់ថ្មី និងអ្នកអាចភ្ជាប់ទៅ វ៉ែបសៃថ៍។', # MODIF
	'pass_mot_oublie' => 'ភ្លេច ពាក្យសំងាត់',
	'pass_nouveau_enregistre' => 'ពាក្យសំងាត់ថ្មី របស់​អ្នក ​ត្រូវ​បានរក្សាទុក។',
	'pass_nouveau_pass' => 'ពាក្យសំងាតថ្មី',
	'pass_ok' => 'យល់ព្រម',
	'pass_oubli_mot' => 'ភ្លេច​ពាក្យសំងាត់',
	'pass_quitter_fenetre' => 'ចាក​ចេញ ពី​បង្អួច​នេះ',
	'pass_rappel_login' => 'ក្រើនរំលឹក ៖ អត្តសញ្ញា របស់​អ្នក (ការពិនិត្យ​ចូល​) គឺ "@login@"។',
	'pass_recevoir_mail' => 'អ្នក​នឹង​ទទួល​បាន ​អ៊ីមែវល៍ ​ដោយ​ពន្យល់​អំពីវិធី រកមើលការចូលទៅ របស់អ្នក លើវ៉ែបសៃថ៍។', # MODIF
	'pass_retour_public' => '​ត្រឡប់​ទៅ វ៉ែបសៃថ៍សាធារណៈ',
	'pass_rien_a_faire_ici' => 'គ្មា​អ្វី​ ត្រូវធ្វើ​ នៅ​ទី​នេះ។',
	'pass_vousinscrire' => 'ចុះ​ឈ្មោះ​អ្នក លើវ៉ែបសៃថ៍ នេះ',
	'precedent' => 'មុន',
	'previsualisation' => '​មើល​​មុន',
	'previsualiser' => '​មើល​មុន',

	// R
	'retour' => 'ត្រលប់ក្រោយ',

	// S
	'spip_conforme_dtd' => 'SPIP យល់ថា ឯកសារនេះ ​ស្រប​តាម DOCTYPE របស់វា ៖',
	'squelette' => 'គ្រោង',
	'squelette_inclus_ligne' => 'រួមបញ្ចូល គ្រោងការងារ, បណ្តាញ',
	'squelette_ligne' => 'គ្រោង, បណ្ដាញ',
	'stats_visites_et_popularite' => '@visites@ ទស្សនា ប្រជាប្រិយភាព​៖ @popularite@',
	'suivant' => 'បន្ទាប់',

	// T
	'taille_ko' => '@taille@ គីឡូបៃ',
	'taille_mo' => '@taille@ មេកាបៃ',
	'taille_octets' => '@taille@ បៃ',
	'taille_octets_bi' => '@taille@ បៃ',
	'texte_actualite_site_1' => '​ពេល​អ្នកស៊ាំ ជាមួយផ្ទាំងប្រទាក់, អ្នកនឹងអាច ចុចលើ «',
	'texte_actualite_site_2' => 'ផ្ទាំង​ប្រទាក់​ ពេញលេញ',
	'texte_actualite_site_3' => '» ដើម្បី​ បើកថែម លទ្ធភាព។',
	'texte_creation_automatique_vignette' => 'ការ​បង្កើត​​ស្វ័យប្រវត្ដិ​ រូបភាព ត្រូវបានសកម្ម ​ក្នុងវ៉ែបសៃថ៍នេះ។ បើ​អ្នកតំលើង ​តាមបែបបទ នៃរូបភាព មានទ្រង់ទ្រាយ @gd_formats@, ពួកវា នឹងនាំមកជាមួយ កូនរូបភាព មានទំហំអតិបរិមា @taille_preview@ pixels។',
	'texte_documents_associes' => 'ឯកសារ​ខាងក្រោម​ ភ្ជាប់ជាមួយអត្ថបទ, ប៉ុន្ដែ​ពួកវា មិនត្រូវបានបញ្ចូល ដោយ​ផ្ទាល់​។ ​ផ្អែក​លើ​ តំរៀបទំព័រ នៃវ៉ែបសៃថ៍សាធារណៈ, ពួកវានឹងអាចបង្ហាញ ក្រោមរូបភាព ជាឯកសារភ្ជាប់។',
	'texte_erreur_mise_niveau_base' => 'កំហុស​ឃ្លាំង​ទិន្នន័យ ​ក្នុងអំឡុង ​ការតំលើងកំរិត។ រូបភាព <b>@fichier@</b> មិនសំរេច​បាន (​អត្ថបទ @id_article@)
។ សូមកត់សំគាល់ បានច្បាស់ ឯកសារយោង​នេះ, ព្យាយាមឡើងវិញ ការតំលើងកំរិត, និងទីបញ្ចប់ ផ្ទៀងផ្ទាត់រូបភាព មានបង្ហាញចេញ ជានិច្ច លើអត្ថបទ ឬអត់។',
	'texte_erreur_visiteur' => 'អ្នក​បាន​ ព្យាយាមចូលទៅ ទី​ឯកជន ជាមួយការពិនិត្យចូល ដែលមិនត្រូវបានអនុញ្ញាតិ ។',
	'texte_inc_auth_1' => 'អ្នកត្រូវ​បាន​ស្គាល់​ ដោយការពិនិត្យចូល <b>@auth_login@</b>, ប៉ុន្ដែ​គ្មាន/លែង​មាន​ក្នុងមូលដ្ឋានទិន្នន័យ។ សូមអ្នក ព្យាយាមឡើងវិញ។',
	'texte_inc_auth_2' => '​ភ្ជាប់​ឡើង​វិញ',
	'texte_inc_auth_3' => ', បន្ទាប់ពីបានចាកចេញ រួចដំណើរឡើងវិញ ឧបកររាវរក របស់អ្នក។',
	'texte_inc_config' => 'បំលាស់ប្ដូរ ​ដែល​បានអនុវត្ត ក្នុងទំព័រនេះ មានឥទ្ធិពល គួរកត់សំគាល់ លើដំណើរការ នៃវ៉ែបសៃថ៍ របស់អ្នក។ យើងអនុសាសអ្នក មិនត្រូវអន្តរាគមក្នុងនោះ បើអ្នកមិនជា គ្រួសារ នៃប្រព័ន្ធការងារ SPIP។ <br /><br /><b> លើសពីហ្នឹង, ជា​ទូទៅ សំណូមពរ ប្រគល់ភារ៖កិច្ច ផ្ទុកទំព័រនេះ អោយទៅអ្នកជំនាញវ៉ែប នៃវ៉ែបសៃថ៍ របស់អ្នក។ </b>',
	'texte_inc_meta_1' => 'ប្រព័ន្ធ​ បានជួបមួយកំហុស ពេលសរសេរ លើសំណុំឯកសារ <code>@fichier@</code>។ ក្នុង​នាម​ជា​អ្នកអភិបាលសៃថ៍, សូម', # MODIF
	'texte_inc_meta_2' => 'ផ្ទៀងផ្ទាត់ សិទ្ធិសរសេរ',
	'texte_inc_meta_3' => 'លើបញ្ជី​រាយ​ឈ្មោះ <code>@repertoire@</code>។',
	'texte_statut_en_cours_redaction' => '​កំពុង តែងអត្ថបទ',
	'texte_statut_poubelle' => 'នៅ​ធុងសំរាម',
	'texte_statut_propose_evaluation' => 'ស្នើការវាយតំលៃ',
	'texte_statut_publie' => 'ផ្សព្វផ្សាយ​ លើអិនរើណែត',
	'texte_statut_refuse' => 'ត្រូវ​បាន ​បដិសេធ',
	'titre_ajouter_mot_cle' => 'បន្ថែម​ មួយពាក្យ​គន្លឹះ ៖',
	'titre_cadre_raccourcis' => 'ផ្លូវ​កាត់ ៖',
	'titre_changer_couleur_interface' => 'ផ្លាស់​ប្ដូរ ​ពណ៌ផ្ទាំង​ប្រទាក់',
	'titre_image_admin_article' => 'អ្នក​អាច​គ្រប់គ្រង​អត្ថបទ​នេះ',
	'titre_image_administrateur' => 'អ្នកគ្រប់គ្រង', # MODIF
	'titre_image_aide' => 'ពីជំនួយ លើធាតុនេះ',
	'titre_image_auteur_supprime' => 'បានលុបចេញ អ្នកនិពន្ធ',
	'titre_image_redacteur' => 'អ្នកតែងអត្ថបទ គ្មានការចូលទៅ',
	'titre_image_redacteur_02' => 'អ្នកតែងអត្ថបទ',
	'titre_image_visiteur' => 'អ្នក​ទស្សនា',
	'titre_joindre_document' => 'ភ្ជាប់​ មួយឯកសារ',
	'titre_mots_cles' => 'ពាក្យ​គន្លឹះ',
	'titre_probleme_technique' => 'ប្រយ័ត្ន ៖ បញ្ហា​បច្ចេកទេស (ខំព្យូរើបំរើសេវា SQL) រាំងខ្ទប់ ការចូលទៅ ផ្នែកនេះ នៃវ៉ែបសៃថ៍។ អរគុណ​ចំពោះ​ការ​យោគយល់​ របស់​អ្នក។',
	'titre_publier_document' => 'ផ្សព្វផ្សាយ មួយ​ឯកសារ ​ក្នុងមាតិកានេះ ៖',
	'titre_signatures_attente' => 'ហត្ថលេខា នៅរង់ចាំសុពលភាព',
	'titre_signatures_confirmees' => 'បានបញ្ជាក់ទទួលស្គាល់ ហត្ថលេខា',
	'titre_statistiques' => 'ស្ថិតិ​ នៃវ៉ែបសៃ៍',
	'titre_titre_document' => 'ចំណងជើង ​ឯកសារ ៖',
	'todo' => 'នឹងមកដល់',
	'trad_reference' => '(​អត្ថបទ​ យោង​)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' ៖ ប្លាក B នៅចុង',
	'zbug_balise_inexistante' => 'កំហុស @from@៖ ប្លាក #@balise@ គ្មានស្រាប់',
	'zbug_balise_sans_argument' => 'ខ្វះ Argument ក្នុងប្លាក @balise@',
	'zbug_boucle' => 'រ​ង្វិ​ល​ជុំ',
	'zbug_boucle_recursive_undef' => 'ការ​ធ្វើរ​ង្វិ​ល​ជុំ​ ជាប់​ៗ​គ្នា គ្មាន​កំណត់៖ @nom@',
	'zbug_calcul' => 'គណនា',
	'zbug_champ_hors_boucle' => 'វាល @champ@ ក្រៅ រង្វិលជុំ',
	'zbug_champ_hors_motif' => 'វាល @champ@ ក្រៅរង្វិលជុំ @motif@',
	'zbug_code' => 'អក្សរកូដ',
	'zbug_critere_inconnu' => 'គ្មានស្គាល់ លក្ខណ្ឌ @critere@',
	'zbug_distant_interdit' => 'ហាម ទិន្នន័យខាងក្រៅ',
	'zbug_doublon_table_sans_cle_primaire' => 'ការបញ្ចូលជាន់គ្នា លើតារាង ដែលគ្មានសោបថម សាមញ្ញ',
	'zbug_doublon_table_sans_index' => 'អត្ថបទផ្ទួន លើ​តារាង ​ដោយ​គ្មានលំដាប់',
	'zbug_erreur_boucle_double' => 'BOUCLE@id@៖ និយមន័យផ្ទួន',
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@៖ ខ្វះប្លាកបិទ',
	'zbug_erreur_boucle_syntaxe' => 'កំហុសពាក្យសម្ពន្ធ វិល​ជុំ​',
	'zbug_erreur_compilation' => 'កំហុស​ ​ចងក្រង',
	'zbug_erreur_execution_page' => 'កំហុស​ ​ប្រតិបត្តិ',
	'zbug_erreur_filtre' => 'តំរង <b>"@filtre@"</b> គ្មានត្រូវបានកំណត់​ ',
	'zbug_erreur_meme_parent' => '{meme_parent} អនុវត្ដត្រឹម​ ការវិល​ជុំ (វេទិកា) ឬ (ផ្នែក)',
	'zbug_erreur_squelette' => 'កំហុស​ ក្នុង គ្រោង',
	'zbug_hors_compilation' => 'ក្រៅការចងក្រង',
	'zbug_info_erreur_squelette' => 'កំហុស​ លើវ៉ែបសៃថ៍',
	'zbug_inversion_ordre_inexistant' => 'ការត្រលប់ នៃ​លំដាប់ គ្មាន​ស្រាប់',
	'zbug_pagination_sans_critere' => 'ប្លាក #PAGINATION គ្មានលក្ខណ្ឌ (ដាក់លេខ​ទំព័រ​​), ឬ ត្រូវបានប្រើប្រាស់ ក្នុងការវិល​ជុំ​ ជាប់​​គ្នា',
	'zbug_parametres_inclus_incorrects' => 'ប៉ារ៉ាម៉ែត្រ​ រួមបញ្ចូល​ មិន​ត្រឹមត្រូវ៖ @param@',
	'zbug_profile' => 'ចំនួនពេលគណនា ៖ @time@',
	'zbug_resultat' => 'លទ្ធផល',
	'zbug_serveur_indefini' => 'គ្មានបានកំណត់ ខំព្យូរើបំរើសេវា SQL',
	'zbug_statistiques' => 'ស្ថិតិ នៃសំណួរអង្កេត SQL ដាក់លំដាប់ តាមរយះពេល',
	'zbug_table_inconnue' => 'គ្មានស្គាល់ តារាង SQL "@table@"',
	'zxml_connus_attributs' => 'បានស្គាល់ សេចក្តីកំណត់',
	'zxml_de' => 'ពី',
	'zxml_inconnu_attribut' => 'គ្មានស្គាល់ សេចក្តីកំណត់',
	'zxml_inconnu_balise' => 'គ្មានស្គាល់ ប្លាក',
	'zxml_inconnu_entite' => 'គ្មានស្គាល់ អង្គភាព',
	'zxml_inconnu_id' => 'គ្មានស្គាល់ អត្តសញ្ញា',
	'zxml_mais_de' => 'ប៉ុន្ដែ​ ​ពី',
	'zxml_non_conforme' => 'គ្មានតាម ហេតុផល',
	'zxml_non_fils' => 'មិនជា​ កូន របស់',
	'zxml_nonvide_balise' => 'ប្លាក​មិនទទេ',
	'zxml_obligatoire_attribut' => 'សេចក្តីកំណត់បង្ខំ ប៉ុន្តែអវត្តមាន ក្នុង',
	'zxml_succession_fils_incorrecte' => 'ការ​បន្ដ​ នៃកូន មិន​ត្រឹមត្រូវ',
	'zxml_survoler' => 'ហោះហើរ ដើម្បីមើល ការត្រឹមត្រូវ',
	'zxml_valeur_attribut' => 'តំលៃ នៃសេចក្តីកំណត់',
	'zxml_vide_balise' => 'ប្លាក​ទទេ',
	'zxml_vu' => 'បានឃើញ ​ពី​មុន',
];
